@@ -169,6 +169,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -189,14 +191,14 @@ class S3ToStepFunction(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_cloud_trail: typing.Optional[builtins.bool] = None,
-        event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
+        event_rule_props: typing.Optional[typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -215,6 +217,10 @@ class S3ToStepFunction(
         :access: public
         :summary: Constructs a new instance of the S3ToStepFunction class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3ToStepFunction.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToStepFunctionProps(
             state_machine_props=state_machine_props,
             bucket_props=bucket_props,
@@ -281,14 +287,14 @@ class S3ToStepFunctionProps:
     def __init__(
         self,
         *,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_cloud_trail: typing.Optional[builtins.bool] = None,
-        event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
+        event_rule_props: typing.Optional[typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -314,6 +320,17 @@ class S3ToStepFunctionProps:
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(S3ToStepFunctionProps.__init__)
+            check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
+            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument deploy_cloud_trail", value=deploy_cloud_trail, expected_type=type_hints["deploy_cloud_trail"])
+            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
+            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
+            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
         self._values: typing.Dict[str, typing.Any] = {
             "state_machine_props": state_machine_props,
         }
